@@ -5,7 +5,7 @@ test_that("plotdelta produces a graph", {
   
   data(MassOutput, envir = environment())
   
-  test <- plotdelta(Dataset = MassOutput)
+  test <- plotdelta(dataset = MassOutput)
   
   expect_true(attr(test, "class")[1] == "gg")
   
