@@ -5,7 +5,7 @@ test_that("plotweights produces a graph", {
   
   data(MassOutput, envir = environment())
   
-  test <- plotweights(Dataset = MassOutput, CW1 = 0.95, CW2 = 0.75, CW3 = 0.25)
+  test <- plotweights(dataset = MassOutput, cw1 = 0.95, cw2 = 0.75, cw3 = 0.25)
   
   expect_true(attr(test, "class")[1] == "gg")
   
